eric7/Globals/__init__.py

branch
eric7
changeset 8327
666c2b81cbb7
parent 8318
962bce857696
child 8346
c2b5cca019a1
diff -r 547319e56c60 -r 666c2b81cbb7 eric7/Globals/__init__.py
--- a/eric7/Globals/__init__.py	Wed May 19 18:16:45 2021 +0200
+++ b/eric7/Globals/__init__.py	Wed May 19 19:53:36 2021 +0200
@@ -326,11 +326,11 @@
     # step 1: check, if the user has configured a tools path
     path = Preferences.getQt("QtToolsDir")
     
     # step 2: try the qt5_applications package
     if not path:
         with contextlib.suppress(ImportError):
-            import qt5_applications
-            path = os.path.join(os.path.dirname(qt5_applications.__file__),
+            import qt6_applications
+            path = os.path.join(os.path.dirname(qt6_applications.__file__),
                                 "Qt", "bin")
             # if qt5-applications is not installed just go to the next step
     
@@ -326,11 +326,11 @@
     path = Preferences.getQt("QtToolsDir")
     
-    # step 2: try the qt5_applications package
+    # step 2: try the qt6_applications package
     if not path:
         with contextlib.suppress(ImportError):

eric ide

mercurial